@@ -29,9 +29,9 @@
 
 from __future__ import division
 
-__version__ = '0.7'
+__version__ = '0.8'
 __all__ = ['Flavor', 'Table', 'Values', 'Literal', 'Column', 'Join',
-    'Asc', 'Desc']
+    'Asc', 'Desc', 'NullsFirst', 'NullsLast', 'format2numeric']
 
 import string
 import warnings
@@ -66,19 +66,26 @@ class Flavor(object):
     Contains the flavor of SQL
 
     Contains:
+        limitstyle - state the type of pagination
         max_limit - limit to use if there is no limit but an offset
         paramstyle - state the type of parameter marker formatting
         ilike - support ilike extension
+        no_as - doesn't support AS keyword for column and table
+        null_ordering - support NULL ordering
         function_mapping - dictionary with Function to replace
     '''
 
     def __init__(self, limitstyle='limit', max_limit=None, paramstyle='format',
-            ilike=False, function_mapping=None):
-        assert limitstyle in ['fetch', 'limit']
+            ilike=False, no_as=False, no_boolean=False, null_ordering=True,
+            function_mapping=None):
+        assert limitstyle in ['fetch', 'limit', 'rownum']
         self.limitstyle = limitstyle
         self.max_limit = max_limit
         self.paramstyle = paramstyle
         self.ilike = ilike
+        self.no_as = no_as
+        self.no_boolean = no_boolean
+        self.null_ordering = null_ordering
         self.function_mapping = function_mapping or {}
 
     @property
@@ -161,6 +168,19 @@ class AliasManager(object):
         return alias(i)
 
 
+def format2numeric(query, params):
+    '''
+    Convert format paramstyle query to numeric paramstyle
+
+    >>> format2numeric('SELECT * FROM table WHERE col = %s', ('foo',))
+    ('SELECT * FROM table WHERE col = :0', ('foo',))
+    >>> format2numeric('SELECT * FROM table WHERE col1 = %s AND col2 = %s',
+    ...     ('foo', 'bar'))
+    ('SELECT * FROM table WHERE col1 = :0 AND col2 = :1', ('foo', 'bar'))
+    '''
+    return (query % tuple(':%i' % i for i, _ in enumerate(params)), params)
+
+
 class Query(object):
     __slots__ = ()
 
@@ -441,7 +461,10 @@ class Select(FromItem, SelectQuery):
     @staticmethod
     def _format_column(column):
         if isinstance(column, As):
-            return '%s AS %s' % (column.expression, column)
+            if Flavor.get().no_as:
+                return '%s %s' % (column.expression, column)
+            else:
+                return '%s AS %s' % (column.expression, column)
         else:
             return str(column)
 
@@ -462,7 +485,48 @@ class Select(FromItem, SelectQuery):
                 windows.add(window_function.window)
                 yield window_function
 
+    def _rownum(self, func):
+        aliases = [c.output_name if isinstance(c, As) else None
+            for c in self.columns]
+
+        def columns(table):
+            if aliases and all(aliases):
+                return [Column(table, alias) for alias in aliases]
+            else:
+                return [Column(table, '*')]
+
+        limitselect = self.select(*columns(self))
+        if self.limit is not None:
+            max_row = self.limit
+            if self.offset is not None:
+                max_row += self.offset
+            limitselect.where = _rownum <= max_row
+        if self.offset is not None:
+            rnum = _rownum.as_('rnum')
+            limitselect.columns += (rnum,)
+            offsetselect = limitselect.select(*columns(limitselect),
+                where=rnum > self.offset)
+            query = offsetselect
+        else:
+            query = limitselect
+
+        self.limit, limit = None, self.limit
+        self.offset, offset = None, self.offset
+        query.for_, self.for_ = self.for_, None
+
+        try:
+            value = func(query)
+        finally:
+            self.limit = limit
+            self.offset = offset
+            self.for_ = query.for_
+        return value
+
     def __str__(self):
+        if (Flavor.get().limitstyle == 'rownum'
+                and (self.limit is not None or self.offset is not None)):
+            return self._rownum(str)
+
         with AliasManager():
             from_ = str(self.from_)
             if self.columns:
@@ -493,6 +557,9 @@ class Select(FromItem, SelectQuery):
 
     @property
     def params(self):
+        if (Flavor.get().limitstyle == 'rownum'
+                and (self.limit is not None or self.offset is not None)):
+            return self._rownum(lambda q: q.params)
         p = []
         p.extend(self._with_params())
         for column in self.columns:
@@ -944,13 +1011,17 @@ class From(list):
             # TODO column_alias
             columns_definitions = getattr(from_, 'columns_definitions',
                 None)
+            if Flavor.get().no_as:
+                alias_template = ' "%s"'
+            else:
+                alias_template = ' AS "%s"'
             # XXX find a better test for __getattr__ which returns Column
             if (alias and columns_definitions
                     and not isinstance(columns_definitions, Column)):
-                return (template + ' AS "%s" (%s)') % (from_, alias,
+                return (template + alias_template + ' (%s)') % (from_, alias,
                     columns_definitions)
             elif alias:
-                return (template + ' AS "%s"') % (from_, alias)
+                return (template + alias_template) % (from_, alias)
             else:
                 return template % from_
         return ', '.join(map(format, self))
@@ -1122,6 +1193,14 @@ class Expression(object):
     def desc(self):
         return Desc(self)
 
+    @property
+    def nulls_first(self):
+        return NullsFirst(self)
+
+    @property
+    def nulls_last(self):
+        return NullsLast(self)
+
 
 class Literal(Expression):
     __slots__ = ('_value')
@@ -1135,15 +1214,35 @@ class Literal(Expression):
         return self._value
 
     def __str__(self):
-        return Flavor.get().param
+        flavor = Flavor.get()
+        if flavor.no_boolean:
+            if self._value is True:
+                return '(1 = 1)'
+            elif self._value is False:
+                return '(1 != 1)'
+        return flavor.param
 
     @property
     def params(self):
+        if Flavor.get().no_boolean:
+            if self._value is True or self._value is False:
+                return ()
         return (self._value,)
 
 Null = None
 
 
+class _Rownum(Expression):
+
+    def __str__(self):
+        return 'ROWNUM'
+
+    @property
+    def params(self):
+        return ()
+_rownum = _Rownum()
+
+
 class Column(Expression):
     __slots__ = ('_from', '_name')
 
@@ -1326,15 +1425,27 @@ class Window(object):
 
 
 class Order(Expression):
-    __slots__ = ('expression')
+    __slots__ = ('_expression')
     _sql = ''
 
     def __init__(self, expression):
         super(Order, self).__init__()
+        self._expression = None
         self.expression = expression
         # TODO USING
 
+    @property
+    def expression(self):
+        return self._expression
+
+    @expression.setter
+    def expression(self, value):
+        assert isinstance(value, (Expression, SelectQuery))
+        self._expression = value
+
     def __str__(self):
+        if isinstance(self.expression, SelectQuery):
+            return '(%s) %s' % (self.expression, self._sql)
         return '%s %s' % (self.expression, self._sql)
 
     @property
@@ -1352,6 +1463,58 @@ class Desc(Order):
     _sql = 'DESC'
 
 
+class NullOrder(Expression):
+    __slots__ = ('expression')
+    _sql = ''
+
+    def __init__(self, expression):
+        super(NullOrder, self).__init__()
+        self.expression = expression
+
+    def __str__(self):
+        if not Flavor.get().null_ordering:
+            return '%s, %s' % (self._case, self.expression)
+        return '%s NULLS %s' % (self.expression, self._sql)
+
+    @property
+    def params(self):
+        p = []
+        if not Flavor.get().null_ordering:
+            p.extend(self.expression.params)
+            p.extend(self._case_values())
+        p.extend(self.expression.params)
+        return tuple(p)
+
+    @property
+    def _case(self):
+        from .conditionals import Case
+        values = self._case_values()
+        if isinstance(self.expression, Order):
+            expression = self.expression.expression
+        else:
+            expression = self.expression
+        return Asc(Case((expression == Null, values[0]), else_=values[1]))
+
+    def _case_values(self):
+        raise NotImplementedError
+
+
+class NullsFirst(NullOrder):
+    __slots__ = ()
+    _sql = 'FIRST'
+
+    def _case_values(self):
+        return (0, 1)
+
+
+class NullsLast(NullOrder):
+    __slots__ = ()
+    _sql = 'LAST'
+
+    def _case_values(self):
+        return (1, 0)
+
+
 class For(object):
     __slots__ = ('_tables', '_type_', 'nowait')
 
