@@ -193,8 +193,27 @@ class TestOperators(unittest.TestCase):
     def test_mod(self):
         for mod in [Mod(self.table.c1, self.table.c2),
                 self.table.c1 % self.table.c2]:
+            self.assertEqual(str(mod), '("c1" %% "c2")')
+            self.assertEqual(mod.params, ())
+
+    def test_mod_paramstyle(self):
+        flavor = Flavor(paramstyle='format')
+        Flavor.set(flavor)
+        try:
+            mod = Mod(self.table.c1, self.table.c2)
+            self.assertEqual(str(mod), '("c1" %% "c2")')
+            self.assertEqual(mod.params, ())
+        finally:
+            Flavor.set(Flavor())
+
+        flavor = Flavor(paramstyle='qmark')
+        Flavor.set(flavor)
+        try:
+            mod = Mod(self.table.c1, self.table.c2)
             self.assertEqual(str(mod), '("c1" % "c2")')
             self.assertEqual(mod.params, ())
+        finally:
+            Flavor.set(Flavor())
 
     def test_pow(self):
         for pow_ in [Pow(self.table.c1, self.table.c2),
@@ -243,7 +262,7 @@ class TestOperators(unittest.TestCase):
         Flavor.set(flavor)
         try:
             like = ILike(self.table.c1, 'foo')
-            self.assertEqual(str(like), '("c1" LIKE %s)')
+            self.assertEqual(str(like), '(UPPER("c1") LIKE UPPER(%s))')
             self.assertEqual(like.params, ('foo',))
         finally:
             Flavor.set(Flavor())
@@ -263,7 +282,7 @@ class TestOperators(unittest.TestCase):
         Flavor.set(flavor)
         try:
             like = NotILike(self.table.c1, 'foo')
-            self.assertEqual(str(like), '("c1" NOT LIKE %s)')
+            self.assertEqual(str(like), '(UPPER("c1") NOT LIKE UPPER(%s))')
             self.assertEqual(like.params, ('foo',))
         finally:
             Flavor.set(Flavor())
@@ -306,5 +325,7 @@ class TestOperators(unittest.TestCase):
             FloorDiv(4, 2)
             self.assertEqual(len(w), 1)
             self.assertTrue(issubclass(w[-1].category, DeprecationWarning))
-            self.assertIn('FloorDiv operator is deprecated, use Div function',
-                str(w[-1].message))
+            if hasattr(self, 'assertIn'):
+                self.assertIn(
+                    'FloorDiv operator is deprecated, use Div function',
+                    str(w[-1].message))
